@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 A S Lewis
+# Copyright (C) 2019-2023 A S Lewis
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """Process operation classes."""
@@ -244,8 +244,8 @@ class ProcessManager(threading.Thread):
     def create_child_process(self, cmd_list):
 
         """Called by self.slice_video() only, in order to concatenate video
-        clips into a single video file. All other child process are handled by
-        ffmpeg_tartube.FFmpegManager.
+        clips into a single video file. All other child processes are handled
+        by ffmpeg_tartube.FFmpegManager.
 
         Based on YoutubeDLDownloader._create_process().
 
@@ -258,7 +258,15 @@ class ProcessManager(threading.Thread):
 
         """
 
+        # Strip double quotes from arguments
+        # (Since we're sending the system command one argument at a time, we
+        #   don't need to retain the double quotes around any single argument
+        #   and, in fact, doing so would cause an error)
+        cmd_list = utils.strip_double_quotes(cmd_list)
+
+        # Create the child process
         info = preexec = None
+
         if os.name == 'nt':
             # Hide the child process window that MS Windows helpfully creates
             #   for us
@@ -332,7 +340,7 @@ class ProcessManager(threading.Thread):
         Called continuously during concatenation of video clips to check
         whether the child process has finished or not.
 
-        Returns:
+        Return values:
 
             True if the child process is alive, otherwise returns False.
 
